#include "interrupts.h"

/******************************************************************************/
/*	Interrupt Routines																												*/
/*	Interrupts that are not used contain an endless loop to make debugging    */
/*  easier.																																		*/
/*																																					  */
/******************************************************************************/



interrupt (BASICTIMER_VECTOR) dummy_BasicTimer_Interrupt(void)
  {
  while (1)
    {}
  }
interrupt (PORT2_VECTOR) dummy_Port2_Interrupt(void)
  {
  while (1)
    {}
  }
interrupt (PORT1_VECTOR) dummy_Port1_Interrupt(void)
  {
  while (1)
    {}
  }

/***************** Timer A0 interrupt service routine *************************/
/* Falling edge at Pin P1.0 rises an interrupt																*/

interrupt(TIMERA0_VECTOR) timer_A (void)
{
  CCR0 += Bitime;                       // Add Offset to CCR0
// RX
  if (CCTL0 & CCIS0) {                   // RX on CCI0A? Is configured as RX?
    if( CCTL0 & CAP ){                   // Capture mode = start bit edge Switch from capture to compare mode, ~CAP means NOT CAP => disable CaptureMode
    	CCTL0 &= ~CAP;
    	CCR0 += Bitime_5;
    }
    else
    {
    	RXTXData = RXTXData >> 1;           
      if (CCTL0 & SCCI)                 // Get bit waiting in receive latch
      	RXTXData |= 0x80;                 
      BitCnt --;                        // All bits RXed?
      if ( BitCnt == 0){ //>>>>>>>>>> Decode of Received Byte Here <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
      	CCTL0 &= ~ CCIE;                  // All bits RXed, disable interrupt
      	_BIC_SR_IRQ(CPUOFF);              // Clear LPM0 bits from 0(SR)
      	//_BIC_SR_IRQ(LPM0);
      }//>>>>>>>>>> Decode of Received Byte Here <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
    }
  }
// TX 
  else {
    if ( BitCnt == 0)
    	CCTL0 &= ~ CCIE;                    // All bits TXed, disable interrupt
    else {
      CCTL0 |=  OUTMOD2;                    // TX Space (0)
      if (RXTXData & 0x01)                 
      	CCTL0 &= ~ OUTMOD2;                 // TX Mark  (1)
      RXTXData = RXTXData >> 1;
      BitCnt --;
    }
  }
}
/* ENDE Timer A0 interrupt service routine */

interrupt (TIMERA1_VECTOR) dummy_TimerAL_Interrupt(void)
  {
  while (1)
    {}
  }
interrupt (WDT_VECTOR) dummy_WDT_Interrupt(void)
  {
  while (1)
    {}
  }
interrupt (COMPARATORA_VECTOR) dummy_ComparatorA_Interrupt(void)
  {
  while (1)
    {}
  }
interrupt (NMI_VECTOR) dummy_NonMaskable_Interrupt(void)
  {
  while (1)
    {}
  }
